@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.2.") or
-    raise "ruby lib version (3.2.9) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.2.10) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.2.0/armv6-netbsdelf-eabihf")
@@ -21,8 +21,8 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "2"
-  CONFIG["TEENY"] = "9"
-  CONFIG["PATCHLEVEL"] = "265"
+  CONFIG["TEENY"] = "10"
+  CONFIG["PATCHLEVEL"] = "266"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/pkg")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)32"
   CONFIG["RUBY_SO_NAME"] = "ruby32"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.2.9.pc"
+  CONFIG["ruby_pc"] = "ruby-3.2.10.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--disable-dtrace' '--program-suffix=32' '--with-soname=ruby32' '--with-ruby-version=3.2.0' '--with-ruby-pc=ruby-3.2.9.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' '--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' 'build_alias=armv6--netbsdelf-eabihf' 'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'CXXFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--disable-dtrace' '--program-suffix=32' '--with-soname=ruby32' '--with-ruby-version=3.2.0' '--with-ruby-pc=ruby-3.2.10.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' '--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' 'build_alias=armv6--netbsdelf-eabihf' 'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -Wno-error=incompatible-pointer-types -Wno-error=declaration-after-statement -Wno-error=deprecated-declarations -Wno-error=implicit-function-declaration -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'CXXFLAGS=-O2 -Wno-error=incompatible-pointer-types -Wno-error=declaration-after-statement -Wno-error=deprecated-declarations -Wno-error=implicit-function-declaration -pthread -I/usr/include -I/usr/pkg/include'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -157,7 +157,7 @@ module RbConfig
   CONFIG["RM"] = "rm -f"
   CONFIG["PKG_CONFIG"] = "pkg-config"
   CONFIG["DOXYGEN"] = ""
-  CONFIG["DOT"] = ""
+  CONFIG["DOT"] = "dot"
   CONFIG["MKDIR_P"] = "/bin/mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
   CONFIG["INSTALL_SCRIPT"] = "$(INSTALL)"
@@ -169,7 +169,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (nb1 20250721) 12.5.0\nCopyright (C) 2022 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (nb1 20250915) 14.3.0\nCopyright (C) 2024 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "gcc"
   CONFIG["CSRCFLAG"] = ""
@@ -179,11 +179,11 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["GCC"] = "yes"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-O2 -pthread -I/usr/include -I/usr/pkg/include"
+  CONFIG["CXXFLAGS"] = "-O2 -Wno-error=incompatible-pointer-types -Wno-error=declaration-after-statement -Wno-error=deprecated-declarations -Wno-error=implicit-function-declaration -pthread -I/usr/include -I/usr/pkg/include"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/usr/include -I/usr/pkg/include $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread -Wl,-export-dynamic -Wl,--no-as-needed"
-  CONFIG["CFLAGS"] = "-O2 -pthread -I/usr/include -I/usr/pkg/include -fPIC -pipe"
+  CONFIG["CFLAGS"] = "-O2 -Wno-error=incompatible-pointer-types -Wno-error=declaration-after-statement -Wno-error=deprecated-declarations -Wno-error=implicit-function-declaration -pthread -I/usr/include -I/usr/pkg/include -fPIC -pipe"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["OBJDUMP"] = "objdump"
@@ -213,7 +213,7 @@ module RbConfig
   CONFIG["RUBY_BASE_NAME"] = "ruby"
   CONFIG["RUBY_PROGRAM_VERSION"] = "$(MAJOR).$(MINOR).$(TEENY)"
   CONFIG["RUBY_API_VERSION"] = "$(MAJOR).$(MINOR)"
-  CONFIG["HAVE_GIT"] = "no"
+  CONFIG["HAVE_GIT"] = "yes"
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
